@@ -1,12 +1,14 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include "utils_global.h"
 
+#include <QBrush>
 #include <QList>
 #include <QString>
+#include <QSyntaxHighlighter>
 
 #include <functional>
 
@@ -16,6 +18,8 @@ QT_END_NAMESPACE
 
 namespace Utils {
 
+class FilePath;
+
 // Create a usable settings key from a category,
 // for example Editor|C++ -> Editor_C__
 QTCREATOR_UTILS_EXPORT QString settingsKey(const QString &category);
@@ -24,19 +28,12 @@ QTCREATOR_UTILS_EXPORT QString settingsKey(const QString &category);
 // "C:\foo\bar1" "C:\foo\bar2"  -> "C:\foo\bar"
 QTCREATOR_UTILS_EXPORT QString commonPrefix(const QStringList &strings);
 
-// Return the common path of a list of files:
-// "C:\foo\bar1" "C:\foo\bar2"  -> "C:\foo"
-QTCREATOR_UTILS_EXPORT QString commonPath(const QStringList &files);
-
-// On Linux/Mac replace user's home path with ~
-// Uses cleaned path and tries to use absolute path of "path" if possible
-// If path is not sub of home path, or when running on Windows, returns the input
-QTCREATOR_UTILS_EXPORT QString withTildeHomePath(const QString &path);
-
 // Removes first unescaped ampersand in text
 QTCREATOR_UTILS_EXPORT QString stripAccelerator(const QString &text);
 // Quotes all ampersands
 QTCREATOR_UTILS_EXPORT QString quoteAmpersands(const QString &text);
+// Convert non-ascii characters into foobar
+QTCREATOR_UTILS_EXPORT QString asciify(const QString &input);
 
 QTCREATOR_UTILS_EXPORT bool readMultiLineString(const QJsonValue &value, QString *out);
 
@@ -68,15 +65,18 @@ QTCREATOR_UTILS_EXPORT QString expandMacros(const QString &str, AbstractMacroExp
 
 QTCREATOR_UTILS_EXPORT int parseUsedPortFromNetstatOutput(const QByteArray &line);
 
+QTCREATOR_UTILS_EXPORT QString appendHelper(const QString &base, int n);
+QTCREATOR_UTILS_EXPORT FilePath appendHelper(const FilePath &base, int n);
+
 template<typename T>
 T makeUniquelyNumbered(const T &preferred, const std::function<bool(const T &)> &isOk)
 {
     if (isOk(preferred))
         return preferred;
     int i = 2;
-    T tryName = preferred + QString::number(i);
+    T tryName = appendHelper(preferred, i);
     while (!isOk(tryName))
-        tryName = preferred + QString::number(++i);
+        tryName = appendHelper(preferred, ++i);
     return tryName;
 }
 
@@ -111,4 +111,31 @@ QTCREATOR_UTILS_EXPORT void setClipboardAndSelection(const QString &text);
 QTCREATOR_UTILS_EXPORT QString chopIfEndsWith(QString str, QChar c);
 QTCREATOR_UTILS_EXPORT QStringView chopIfEndsWith(QStringView str, QChar c);
 
+QTCREATOR_UTILS_EXPORT QString normalizeNewlines(const QString &text);
+
+// Skips empty parts - see QTBUG-110900
+QTCREATOR_UTILS_EXPORT QString joinStrings(const QStringList &strings, QChar separator);
+QTCREATOR_UTILS_EXPORT QString trimFront(const QString &string, QChar ch);
+QTCREATOR_UTILS_EXPORT QString trimBack(const QString &string, QChar ch);
+QTCREATOR_UTILS_EXPORT QString trim(const QString &string, QChar ch);
+
+QTCREATOR_UTILS_EXPORT QPair<QStringView, QStringView> splitAtFirst(const QString &string, QChar ch);
+QTCREATOR_UTILS_EXPORT QPair<QStringView, QStringView> splitAtFirst(const QStringView &stringView,
+                                                                    QChar ch);
+
+QTCREATOR_UTILS_EXPORT int endOfNextWord(const QString &string, int position = 0);
+
+class QTCREATOR_UTILS_EXPORT MarkdownHighlighter : public QSyntaxHighlighter
+{
+public:
+    MarkdownHighlighter(QTextDocument *parent);
+    void highlightBlock(const QString &text) override;
+
+private:
+    QBrush codeBgBrush();
+
+    QBrush h2Brush;
+    QBrush m_codeBgBrush;
+};
+
 } // namespace Utils
